@@ -218,8 +218,11 @@ class Witter():
 
     def enterPressed(self, widget, *args):
         self.ui.showBusy(1)
+        print "sending tweet"
         result = self.activeAccount.newTweet(self.ui.getEntryText(), reply_to_name=self.reply_to_name, reply_to_id=self.reply_to)
+        print "Tweet Sent"
         if (result == True):
+            print "Tweet successful"
             hildon.hildon_banner_show_information(self.ui.window, "", "Tweet Successful")
             #tweet successful, clear tweet text
             self.ui.setTweetText("")
@@ -227,6 +230,7 @@ class Witter():
             if (self.ui.getCurrentView == self.ui.SEARCH_VIEW):
     		    self.ui.setTweetText(self.search_terms)
         else:
+            print "Tweet Failed"
             hildon.hildon_banner_show_information(self.ui.window, "", "Tweet Failed")
         self.ui.showBusy(-1)
 
@@ -622,10 +626,10 @@ class Witter():
             # upload binary file with pycurl by http post
             c = pycurl.Curl()
             c.setopt(c.POST, 1)
-            c.setopt(c.URL, "http: // twitpic.com / api / uploadAndPost")
+            c.setopt(c.URL, "http://twitpic.com/api/uploadAndPost")
             c.setopt(c.HTTPPOST, [("media", (c.FORM_FILE, file)),
-                                  ("username", self.username),
-                                  ("password", self.password),
+                                  ("username", self.activeAccount.getUsername()),
+                                  ("password", self.activeAccount.getPassword()),
                                   ("message", tweet)])
             #c.setopt(c.VERBOSE, 1)
             c.perform()
@@ -640,6 +644,7 @@ class Witter():
             # at you Mauku)
             #self.wTree.get_widget("TweetText").set_text("")
             self.ui.setTweetText("")
+            dialog.hide()
         except IOError:
             print "couldn't read file"
         print file
